v1alpha1

package
v0.0.0-...-1d214fe Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 19, 2017 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	TPRPersistenceActionsKind = "PersistenceAction"
	TPRPersistenceActionName  = "persistenceactions"
)
const (
	TPRGroup   = "persistence.mmerrill3.com"
	TPRVersion = "v1alpha1"
)
const (
	TPRPersistenceInstancesKind = "PersistenceInstance"
	TPRPersistenceInstanceName  = "persistenceinstances"
)

Variables

This section is empty.

Functions

func UnstructuredFromPersistenceAction

func UnstructuredFromPersistenceAction(s *PersistenceAction) (*unstructured.Unstructured, error)

UnstructuredFromPersistenceAction marshals a PersistenceAction object into dynamic client's unstructured

func UnstructuredFromPersistenceInstance

func UnstructuredFromPersistenceInstance(s *PersistenceInstance) (*unstructured.Unstructured, error)

UnstructuredFromPersistenceInstance marshals a PersistenceInstance object into dynamic client's unstructured

Types

type PersistenceAction

type PersistenceAction struct {
	metav1.TypeMeta `json:",inline"`
	// Standard object’s metadata. More info:
	// http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// Specification of the desired behavior of the PersistenceAction. More info:
	// http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status
	Spec PersistenceActionSpec `json:"spec"`
	// Most recent observed status of the PersistenceAction. Read-only. Not
	// included when requesting from the apiserver, only from the Persistence
	// Operator API itself. More info:
	// http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status
	Status *PersistenceActionStatus `json:"status,omitempty"`
}

defines a Persistence Action

func PersistenceActionFromUnstructured

func PersistenceActionFromUnstructured(r *unstructured.Unstructured) (*PersistenceAction, error)

PersistenceActionFromUnstructured unmarshals a PersistenceAction object from dynamic client's unstructured

type PersistenceActionGetter

type PersistenceActionGetter interface {
	PersistenceActions(namespace string) PersistenceActionInterface
}

type PersistenceActionInterface

type PersistenceActionInterface interface {
	Create(*PersistenceAction) (*PersistenceAction, error)
	Get(name string) (*PersistenceAction, error)
	Update(*PersistenceAction) (*PersistenceAction, error)
	Delete(name string, options *metav1.DeleteOptions) error
	List(opts metav1.ListOptions) (runtime.Object, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
}

type PersistenceActionList

type PersistenceActionList struct {
	metav1.TypeMeta `json:",inline"`
	// Standard list metadata
	// More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata
	metav1.ListMeta `json:"metadata,omitempty"`
	// List of PersistenceActionList
	Items []*PersistenceAction `json:"items"`
}

PersistenceActionList is a list of PersistenceActions.

type PersistenceActionSpec

type PersistenceActionSpec struct {
	// ServiceMonitors to be selected for target discovery.
	PersistenceInstanceSelector *metav1.LabelSelector `json:"persistenceInstanceSelector,omitempty"`
	// Whether a persistence action is applied already.  Make it a no-operation
	Applied bool `json:"applied,omitempty"`
	// Define resources requests and limits for Pods.
	Resources v1.ResourceRequirements `json:"resources,omitempty"`
	// Define which Nodes the Pods are scheduled on.
	NodeSelector map[string]string `json:"nodeSelector,omitempty"`
	// ServiceAccountName is the name of the ServiceAccount to use to run the
	// PersistenceAction Pods.
	ServiceAccountName string `json:"serviceAccountName,omitempty"`
	// Define which tolerations are appicable for the pods
	Tolerations []v1.Toleration `json:"tolerations,omitempty"`
	// The time that the action will be ran
	ApplicationTime *metav1.Time `json:"applicationTime"`
	// The actual actions to run.  Every value in the list will be executed in literal order
	Actions []string `json:"actions"`
}

Specification of the desired behavior of the PersistenceAction. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status

type PersistenceActionStatus

type PersistenceActionStatus struct {
	// Represents whether the action has been performed
	Applied bool `json:"paused"`
	// The time that the action started exectuion
	ExecutionTime *metav1.Time `json:"executionTime"`
	// The time that the action completed
	CompletionTime *metav1.Time `json:"completionTime"`
}

Most recent observed status of a PersistenceAction. Read-only. Not included when requesting from the apiserver, only from the Persistence Operator API itself. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status

type PersistenceInstance

type PersistenceInstance struct {
	metav1.TypeMeta `json:",inline"`
	// Standard object’s metadata. More info:
	// http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// Specification of the desired behavior of the PersistenceInstance. More info:
	// http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status
	Spec PersistenceInstanceSpec `json:"spec"`
}

defines a Persistence Instance

func PersistenceInstanceFromUnstructured

func PersistenceInstanceFromUnstructured(r *unstructured.Unstructured) (*PersistenceInstance, error)

PersistenceInstanceFromUnstructured unmarshals a PersistenceInstance object from dynamic client's unstructured

type PersistenceInstanceGetter

type PersistenceInstanceGetter interface {
	PersistenceInstances(namespace string) PersistenceInstanceInterface
}

type PersistenceInstanceInterface

type PersistenceInstanceInterface interface {
	Create(*PersistenceInstance) (*PersistenceInstance, error)
	Get(name string) (*PersistenceInstance, error)
	Update(*PersistenceInstance) (*PersistenceInstance, error)
	Delete(name string, options *metav1.DeleteOptions) error
	List(opts metav1.ListOptions) (runtime.Object, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
}

type PersistenceInstanceList

type PersistenceInstanceList struct {
	metav1.TypeMeta `json:",inline"`
	// Standard list metadata
	// More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata
	metav1.ListMeta `json:"metadata,omitempty"`
	// List of PersistenceInstance
	Items []*PersistenceInstance `json:"items"`
}

PersistenceInstanceList is a list of PersistenceInstances.

type PersistenceInstanceSpec

type PersistenceInstanceSpec struct {
	// One of Oracle, Postgres, MySQL, Mongo
	PersistenceType string `json:"persistenceType"`
	// The name of the secret containing the username, in the same namespace as the
	// PersistenceInstance
	UsernameSecret string `json:"usernameSecret,omitempty"`
	// The name of the secret containing the password, in the same namespace as the
	// PersistenceInstance
	PasswordSecret string `json:"passwordSecret,omitempty"`
	// The url of the persistence
	URL string `json:"url"`
	// The port of the persistence
	Port int32 `json:"port"`
}

Specification of the desired behavior of the PersistenceAction. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#spec-and-status

type PersistenceV1alpha1Client

type PersistenceV1alpha1Client struct {
	// contains filtered or unexported fields
}

func NewForConfig

func NewForConfig(c *rest.Config) (*PersistenceV1alpha1Client, error)

func (*PersistenceV1alpha1Client) PersistenceActions

func (c *PersistenceV1alpha1Client) PersistenceActions(namespace string) PersistenceActionInterface

Jump to